package com.inspect.metadata.eqpbook.service.impl;

import com.inspect.metadata.eqpbook.domain.BasedataEqpBookNvr;
import com.inspect.metadata.eqpbook.mapper.BasedataEqpBookNvrMapper;
import com.inspect.metadata.eqpbook.service.IBasedataEqpBookNvrService;
import com.inspect.metadata.statis.domain.BasedataStatisNvr;
import com.inspect.base.core.utils.DateUtils;
import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class BasedataEqpBookNvrServiceImpl implements IBasedataEqpBookNvrService {
   @Autowired
   private BasedataEqpBookNvrMapper basedataEqpbookNvrMapper;

   public BasedataEqpBookNvr selectBasedataEqpBookNvrByNvrId(Long nvrId) {
      return this.basedataEqpbookNvrMapper.selectBasedataEqpBookNvrByNvrId(nvrId);
   }

   public List<BasedataEqpBookNvr> selectBasedataEqpbookNvrList(BasedataEqpBookNvr basedataEqpbookNvr) {
      return this.basedataEqpbookNvrMapper.selectBasedataEqpBookNvrList(basedataEqpbookNvr);
   }

   public int insertBasedataEqpBookNvr(BasedataEqpBookNvr basedataEqpbookNvr) {
      basedataEqpbookNvr.setCreateTime(DateUtils.getNowDate());
      return this.basedataEqpbookNvrMapper.insertBasedataEqpBookNvr(basedataEqpbookNvr);
   }

   public int updateBasedataEqpBookNvr(BasedataEqpBookNvr basedataEqpbookNvr) {
      return this.basedataEqpbookNvrMapper.updateBasedataEqpBookNvr(basedataEqpbookNvr);
   }

   public int deleteBasedataEqpBookNvrByNvrIds(Long[] nvrIds) {
      return this.basedataEqpbookNvrMapper.deleteBasedataEqpBookNvrByNvrIds(nvrIds);
   }

   public int deleteBasedataEqpBookNvrByNvrId(Long nvrId) {
      return this.basedataEqpbookNvrMapper.deleteBasedataEqpBookNvrByNvrId(nvrId);
   }

   public List<BasedataStatisNvr> selectNewInfo() {
      return this.basedataEqpbookNvrMapper.selectNewInfo();
   }
}
